﻿Imports DotNetBrowser
Imports DotNetBrowser.WinForms


Public Class ProxyTabPage
    Inherits TabPage

    Private proxyConfig As ProxyConfig
    Private contextDirectory As String
    Private context As BrowserContext
    Private browser As Browser
    Private browserView As WinFormsBrowserView

    Public Sub New(ByVal proxyConfig As ProxyConfig)
        Me.proxyConfig = proxyConfig
        contextDirectory = Guid.NewGuid().ToString("N")
        Text = If(proxyConfig IsNot Nothing, proxyConfig.ToString(), "Direct access")
        InitializeBrowser()
    End Sub

    Public Sub GoToUrl(ByVal url As String)
        browser.LoadURL(url)
    End Sub

    Private Sub InitializeBrowser()
        Dim contextParams As BrowserContextParams = New BrowserContextParams(contextDirectory)
        contextParams.StorageType = StorageType.MEMORY

        If proxyConfig IsNot Nothing Then
            contextParams.ProxyConfig = New CustomProxyConfig(String.Format("http={0};https={0};socks={0}",
                                                                            proxyConfig.ToString()))
        End If

        context = New BrowserContext(contextParams)

        If proxyConfig IsNot Nothing AndAlso proxyConfig.IsAuthRequired Then
            context.NetworkService.NetworkDelegate = New ProxyNetworkDelegate(proxyConfig.Username, proxyConfig.Password)
        End If

        browser = BrowserFactory.Create(context)
        browserView = New WinFormsBrowserView(browser) With {
            .Dock = DockStyle.Fill
            }
        Controls.Add(browserView)
    End Sub

    Public Sub DisposeBrowser()
        browserView.Dispose()
        browser.Dispose()
        context.Dispose()
    End Sub
End Class